@@ -1920,3 +1920,119 @@ def test_iso639(pyi_builder):
         from iso639 import Lang
         test = Lang("en")
     """)
+
+
+# Check that `numba.cloudpickle.cloudpickle_fast` is collected even if it is not directly imported anywhere.
+@importorskip('numba')
+def test_numba_cloudpickle_fast(pyi_builder):
+    pyi_builder.test_source("""
+        # Assume the application or its dependencies import numba somewhere.
+        import numba
+
+        # Simulate indirect import of `numba.cloudpickle.cloudpickle_fast`that would happen during data unpickling.
+        import importlib
+        modname = "numba.cloudpickle.cloudpickle_fast"
+        mod = importlib.import_module(modname)
+    """)
+
+
+# Check that `cloudpickle.cloudpickle_fast` is collected even if it is not directly imported anywhere.
+@importorskip('cloudpickle')
+def test_cloudpickle_fast(pyi_builder):
+    pyi_builder.test_source("""
+        # Assume the application or its dependencies import cloudpickle somewhere.
+        import cloudpickle
+
+        # Simulate indirect import of `cloudpickle.cloudpickle_fast`that would happen during data unpickling.
+        import importlib
+        modname = "cloudpickle.cloudpickle_fast"
+        mod = importlib.import_module(modname)
+    """)
+
+
+# Check if pptx template is included
+@importorskip('pptx')
+def test_pptx(pyi_builder):
+    pyi_builder.test_source("""
+        import pptx
+        pptx.Presentation()
+    """)
+
+
+@importorskip('opentelemetry.sdk')
+def test_opentelemetry(pyi_builder):
+    # Basic tracer example, taken from
+    # https://github.com/open-telemetry/opentelemetry-python/blob/main/docs/examples/basic_tracer/basic_trace.py
+    pyi_builder.test_source("""
+        from opentelemetry import trace
+        from opentelemetry.sdk.trace import TracerProvider
+        from opentelemetry.sdk.trace.export import (
+            BatchSpanProcessor,
+            ConsoleSpanExporter,
+        )
+
+        trace.set_tracer_provider(TracerProvider())
+        trace.get_tracer_provider().add_span_processor(
+            BatchSpanProcessor(ConsoleSpanExporter())
+        )
+        tracer = trace.get_tracer(__name__)
+        with tracer.start_as_current_span("foo"):
+            print("Hello world!")
+    """)
+
+
+# Basic test for cryptography package
+@importorskip('cryptography')
+def test_cryptography(pyi_builder):
+    pyi_builder.test_source("""
+        from cryptography.fernet import Fernet
+
+        key = Fernet.generate_key()
+        f = Fernet(key)
+
+        token = f.encrypt(b"This is test.")
+        print(f"Encrypted message: {token}")
+
+        print(f"Decrypted message: {f.decrypt(token)}")
+    """)
+
+
+@importorskip('xarray')
+def test_xarray(pyi_builder):
+    pyi_builder.test_source("""
+        import xarray as xr
+        import numpy as np
+
+        data = xr.DataArray(
+            np.random.randn(2, 3),
+            dims=("x", "y"),
+            coords={"x": [10, 20]},
+        )
+        print(data)
+    """)
+
+
+@importorskip('tables')
+def test_pytables(pyi_builder):
+    # NOTE: run_from_path=True prevents `pyi_builder` from completely clearing the `PATH` environment variable. At the
+    # time of writing, `cpu_info` (used by PyTables) raises error if `PATH` is missing from `os.environ`.
+    pyi_builder.test_source("""
+        # `tables` uses cpu_info package during initialization, which in turn uses `multiprocessing`, so we need to call
+        # `multiprocessing.freeze_support()` before importing `tables`.
+        import multiprocessing
+        multiprocessing.freeze_support()
+
+        import tables
+    """, run_from_path=True)
+
+
+@importorskip('schwifty')
+def test_schwifty(pyi_builder):
+    pyi_builder.test_source("""
+        import schwifty
+
+        iban = schwifty.IBAN('DE89 3704 0044 0532 0130 00')
+        print(iban.country_code)
+        print(iban.bank_code)
+        print(iban.account_code)
+    """)
